@@ -35,6 +35,7 @@ ARTEFACTS = [
     "scp_fw.bin",
     "scp_romfw.bin",
     "fip.bin",
+    "ubuntu.satadisk.xz",
 ]
 
 FVP_MORELLO_ANDROID = [
@@ -201,6 +202,15 @@ def artefacts(tmp_path):
             ],
             "qemu-mips32-modules.yaml",
         ),
+        (
+            [
+                "--device",
+                "qemu-mips32",
+                "--modules",
+                "https://example.com/modules.tgz",
+            ],
+            "qemu-mips32-modules-tgz.yaml",
+        ),
         (
             [
                 "--device",
@@ -288,6 +298,75 @@ def artefacts(tmp_path):
             ],
             "qemu-x86_64-rootfs-gz.yaml",
         ),
+        (
+            [
+                "--device",
+                "fvp-aemva",
+                "--bl1",
+                "tf-bl1.bin",
+                "--fip",
+                "fip.bin",
+                "--kernel",
+                "zImage.xz",
+                "--rootfs",
+                "https://example.com/rootfs.ext4.zst",
+            ],
+            "fvp-aemva-kernel-xz.yaml",
+        ),
+        (
+            [
+                "--device",
+                "fvp-aemva",
+                "--bl1",
+                "tf-bl1.bin",
+                "--fip",
+                "fip.bin",
+                "--rootfs",
+                "https://example.com/rootfs.ext4.zst",
+                "--tests",
+                "ltp-smoke",
+            ],
+            "fvp-aemva-ltp-smoke.yaml",
+        ),
+        (
+            [
+                "--device",
+                "fvp-aemva",
+                "--bl1",
+                "tf-bl1.bin",
+                "--fip",
+                "fip.bin",
+                "--rootfs",
+                "https://example.com/rootfs.ext4.zst",
+            ],
+            "fvp-aemva.yaml",
+        ),
+        (
+            [
+                "--device",
+                "fvp-aemva",
+                "--bl1",
+                "tf-bl1.bin",
+                "--fip",
+                "fip.bin",
+                "--modules",
+                "https://example.com/modules.tar.xz",
+            ],
+            "fvp-aemva-modules.yaml",
+        ),
+        (
+            [
+                "--device",
+                "fvp-aemva",
+                "--bl1",
+                "tf-bl1.bin",
+                "--fip",
+                "fip.bin",
+                "--modules",
+                "https://example.com/modules.tar.gz",
+            ],
+            "fvp-aemva-modules-tar-gz.yaml",
+        ),
         (
             ["--device", "fvp-morello-android", *FVP_MORELLO_ANDROID],
             "fvp-morello-android.yaml",
@@ -490,6 +569,29 @@ def artefacts(tmp_path):
             ],
             "fvp-morello-busybox.yaml",
         ),
+        (
+            [
+                "--device",
+                "fvp-morello-busybox",
+                "--ap-romfw",
+                "tf-bl1.bin",
+                "--mcp-fw",
+                "mcp_fw.bin",
+                "--mcp-romfw",
+                "mcp_romfw.bin",
+                "--rootfs",
+                "busybox.img.xz",
+                "--scp-fw",
+                "scp_fw.bin",
+                "--scp-romfw",
+                "scp_romfw.bin",
+                "--fip",
+                "fip.bin",
+                "--tests",
+                "purecap",
+            ],
+            "fvp-morello-busybox-purecap.yaml",
+        ),
         (
             [
                 "--device",
