@@ -10,18 +10,22 @@ from pathlib import Path
 
 import jinja2
 
+from tuxrun.utils import compression
+
 
 BASE = (Path(__file__) / "..").resolve()
 
 
 @lru_cache(maxsize=None)
 def jobs():
-    return jinja2.Environment(
+    env = jinja2.Environment(
         autoescape=False,
         trim_blocks=True,
         loader=jinja2.FileSystemLoader(str(BASE / "jobs")),
         undefined=jinja2.StrictUndefined,
     )
+    env.globals["compression"] = compression
+    return env
 
 
 @lru_cache(maxsize=None)
